==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d8/d61/network__widget_8h.js <==
var network__widget_8h =
[
    [ "ClientListPopupWidgets", "d8/d61/network__widget_8h.html#acbe134caab35fb626b80d92079e2143c", [
      [ "WID_CLP_PANEL", "d8/d61/network__widget_8h.html#acbe134caab35fb626b80d92079e2143ca1949f70c0e4f2cc88a01b277d97a49a2", null ]
    ] ],
    [ "ClientListWidgets", "d8/d61/network__widget_8h.html#a835b24cc99161c94414f6528d38b14fc", [
      [ "WID_CL_PANEL", "d8/d61/network__widget_8h.html#a835b24cc99161c94414f6528d38b14fca7db8a46161146cc635d32c389be68008", null ]
    ] ],
    [ "NetworkCompanyPasswordWidgets", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014", [
      [ "WID_NCP_BACKGROUND", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014afa09c10f819622a085b358efade0e4f5", null ],
      [ "WID_NCP_LABEL", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a8318b8ca1e6d92f6e491cd95d49dae28", null ],
      [ "WID_NCP_PASSWORD", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a120b8e83554cfa8a1c2393f40ef0f7bf", null ],
      [ "WID_NCP_SAVE_AS_DEFAULT_PASSWORD", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a007d1e787ccf5d80e9714e522de7ceb8", null ],
      [ "WID_NCP_CANCEL", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014ad0c1beb2a9cff2022e21d99bdd74f69d", null ],
      [ "WID_NCP_OK", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a3a6b9ad5c54a1427455832b2b3097d4f", null ]
    ] ],
    [ "NetworkGameWidgets", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45", [
      [ "WID_NG_MAIN", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45ae339fd8e9f719c6ddf901bb94c4b51de", null ],
      [ "WID_NG_CONNECTION", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a7ff28e78e851ae2e246f9e5a80c09d8c", null ],
      [ "WID_NG_CONN_BTN", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a87eceb1eb1dbb00808b4b24fd4b83996", null ],
      [ "WID_NG_CLIENT_LABEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a889aadba558c30fb4c4a8e7b6c0c8223", null ],
      [ "WID_NG_CLIENT", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a01e09e0e470d066e3d251dd2706e1844", null ],
      [ "WID_NG_FILTER_LABEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a3fc1425dfcc3c7e9485ff0dd4754ccef", null ],
      [ "WID_NG_FILTER", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aebb244c75fe9fdc629db7d10fffdb97f", null ],
      [ "WID_NG_HEADER", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a075c59ddb33422e101305235efdfbf42", null ],
      [ "WID_NG_NAME", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45ac2f3e2da170056945967ed1018181dec", null ],
      [ "WID_NG_CLIENTS", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a0c8b7ae545cc8d28496ecdb0a73c6bb9", null ],
      [ "WID_NG_MAPSIZE", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aa397f817c0c224f0a2ef56226ef81f84", null ],
      [ "WID_NG_DATE", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a778cc29c33284d902b62a17aec6ce631", null ],
      [ "WID_NG_YEARS", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a33996241b9a4c8673b68f363d3f55ddf", null ],
      [ "WID_NG_INFO", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aaebaead8491d0963e77eb03865ae8e8d", null ],
      [ "WID_NG_MATRIX", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a7ae8bb002bbbc1fd44d277fa6a9013c8", null ],
      [ "WID_NG_SCROLLBAR", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a1eef989849fa807d1147ad49fd1cf967", null ],
      [ "WID_NG_LASTJOINED_LABEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45af12260e504eb69235b5ff7073b3dd296", null ],
      [ "WID_NG_LASTJOINED", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a79b38375b7fa9faa22536d799179ff21", null ],
      [ "WID_NG_LASTJOINED_SPACER", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a766140d28c203c81dd00613d0318fc3a", null ],
      [ "WID_NG_DETAILS", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aa5dc5cd8b103625f6c0d686e0cc969b4", null ],
      [ "WID_NG_DETAILS_SPACER", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45adfe15c2e7fcea014b05705eb2abdd8fe", null ],
      [ "WID_NG_JOIN", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a940e7423adc7abc1aae0bd4e21d23879", null ],
      [ "WID_NG_REFRESH", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45ae3561e0bd887108906a495b424250d6c", null ],
      [ "WID_NG_NEWGRF", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45af3554c1b58b78df1c0226a4984539cdc", null ],
      [ "WID_NG_NEWGRF_SEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a8e6e742407c970c624e570ce41164ad7", null ],
      [ "WID_NG_NEWGRF_MISSING", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a73f1afe6899c6f7d2c1fc4cf7ecadce7", null ],
      [ "WID_NG_NEWGRF_MISSING_SEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a49f296666543b39ad4eaa56ac16637eb", null ],
      [ "WID_NG_FIND", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a8bd3c84d6a851e1f540e9bad9f58769a", null ],
      [ "WID_NG_ADD", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45acf12ff8dd6f1b4158f22c746a47a91a1", null ],
      [ "WID_NG_START", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aa522a2402d1ac27481caa2057fd5f746", null ],
      [ "WID_NG_CANCEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45ac7762180c1a2540351087e2b57280377", null ]
    ] ],
    [ "NetworkJoinStatusWidgets", "d8/d61/network__widget_8h.html#a763130b21af0ad7e580ddee81a70a6b8", [
      [ "WID_NJS_BACKGROUND", "d8/d61/network__widget_8h.html#a763130b21af0ad7e580ddee81a70a6b8a6de9aafb5a70cea652951f045a57d822", null ],
      [ "WID_NJS_CANCELOK", "d8/d61/network__widget_8h.html#a763130b21af0ad7e580ddee81a70a6b8ab1657760fc411c762cc227baee73e013", null ]
    ] ],
    [ "NetworkLobbyWidgets", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220", [
      [ "WID_NL_BACKGROUND", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a05b7f5c774227b0438cc7b7c6eb721bf", null ],
      [ "WID_NL_TEXT", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a0dd2a8b5ed8db4b188494a9bb630a8fc", null ],
      [ "WID_NL_HEADER", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220aa0480c1dbae3996955d158d683efecca", null ],
      [ "WID_NL_MATRIX", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220ad52da3286b68fab063dfb104a8bfad61", null ],
      [ "WID_NL_SCROLLBAR", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a57c46cfcd5c5f4a24a8f0a18bdd5a3e1", null ],
      [ "WID_NL_DETAILS", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220af79cb692bffc5981486f40759d566980", null ],
      [ "WID_NL_JOIN", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220ae057b7478bfb28c97aa14f5062bf5b10", null ],
      [ "WID_NL_NEW", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a3000949b02779104d482bcbce55e8afe", null ],
      [ "WID_NL_SPECTATE", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220aa690bee3902240b34119b88fb113feba", null ],
      [ "WID_NL_REFRESH", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220aa60c961eb88e777df4a2d517cabd86c3", null ],
      [ "WID_NL_CANCEL", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a8573c5bdac77291a456af1ec56ebe717", null ]
    ] ],
    [ "NetworkStartServerWidgets", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833", [
      [ "WID_NSS_BACKGROUND", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833af52d2afb64869e427d62a35bc17c9974", null ],
      [ "WID_NSS_GAMENAME_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a867bda307263cbf4967419baabed42f5", null ],
      [ "WID_NSS_GAMENAME", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a508cd3b44b352da718f8f83db274cf3c", null ],
      [ "WID_NSS_SETPWD", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ad519409efa1ecf8b9493f068136e198d", null ],
      [ "WID_NSS_CONNTYPE_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ac5324995abb303eeb4480730f93b1f9e", null ],
      [ "WID_NSS_CONNTYPE_BTN", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ac8b47c2be7e1e0ac5c13db3c9b866e29", null ],
      [ "WID_NSS_CLIENTS_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a200a60df467983743c7da56957d4419e", null ],
      [ "WID_NSS_CLIENTS_BTND", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a4fb8af97abbb32965b935dacfc7fb71b", null ],
      [ "WID_NSS_CLIENTS_TXT", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a4dd014db65815066da2ec59568218f32", null ],
      [ "WID_NSS_CLIENTS_BTNU", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833aeafeb1fceaa8af11999def1eb102d8fe", null ],
      [ "WID_NSS_COMPANIES_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a1e368de3d28b73fe0429e2e97f982463", null ],
      [ "WID_NSS_COMPANIES_BTND", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ad3c55eb8d34c14d367d7cf20f04b012c", null ],
      [ "WID_NSS_COMPANIES_TXT", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833aed786417e69a6faa1b3f2efb9313ee91", null ],
      [ "WID_NSS_COMPANIES_BTNU", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a14679fea39052542c828cde07428e5b9", null ],
      [ "WID_NSS_SPECTATORS_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ab21f43474c57c9952f91b1e7d254972b", null ],
      [ "WID_NSS_SPECTATORS_BTND", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a79533e6f35d4e734910873c3bc0efea4", null ],
      [ "WID_NSS_SPECTATORS_TXT", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833accb8eaff704a804b3cdf29dd83505e7d", null ],
      [ "WID_NSS_SPECTATORS_BTNU", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a0c96a06d779fef36fdd0292c09ff74f9", null ],
      [ "WID_NSS_LANGUAGE_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a4d006e0ef2eb28d4b8c89bd8d45d4e79", null ],
      [ "WID_NSS_LANGUAGE_BTN", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a5a31c158e30b06d108b4c4593ca90b09", null ],
      [ "WID_NSS_GENERATE_GAME", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ac1a6d8a773fe7fc6a808aa02af5a4901", null ],
      [ "WID_NSS_LOAD_GAME", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833aa7a9a1ad4a8a9be1dd96aa067a1479fc", null ],
      [ "WID_NSS_PLAY_SCENARIO", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833af6414f0ac0bc6d27e392143eeb747c73", null ],
      [ "WID_NSS_PLAY_HEIGHTMAP", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a7062ae05eeb8b6ad9be6946d1cab5e79", null ],
      [ "WID_NSS_CANCEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a6d36e6ba137e2e41abb57509f85e16c6", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d8/d61/network__widget_8h.js <==
var network__widget_8h =
[
    [ "ClientListPopupWidgets", "d8/d61/network__widget_8h.html#acbe134caab35fb626b80d92079e2143c", [
      [ "WID_CLP_PANEL", "d8/d61/network__widget_8h.html#acbe134caab35fb626b80d92079e2143ca1949f70c0e4f2cc88a01b277d97a49a2", null ]
    ] ],
    [ "ClientListWidgets", "d8/d61/network__widget_8h.html#a835b24cc99161c94414f6528d38b14fc", [
      [ "WID_CL_PANEL", "d8/d61/network__widget_8h.html#a835b24cc99161c94414f6528d38b14fca7db8a46161146cc635d32c389be68008", null ]
    ] ],
    [ "NetworkCompanyPasswordWidgets", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014", [
      [ "WID_NCP_BACKGROUND", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014afa09c10f819622a085b358efade0e4f5", null ],
      [ "WID_NCP_LABEL", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a8318b8ca1e6d92f6e491cd95d49dae28", null ],
      [ "WID_NCP_PASSWORD", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a120b8e83554cfa8a1c2393f40ef0f7bf", null ],
      [ "WID_NCP_SAVE_AS_DEFAULT_PASSWORD", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a007d1e787ccf5d80e9714e522de7ceb8", null ],
      [ "WID_NCP_WARNING", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a614f540a8610c2d358a1390f59367460", null ],
      [ "WID_NCP_CANCEL", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014ad0c1beb2a9cff2022e21d99bdd74f69d", null ],
      [ "WID_NCP_OK", "d8/d61/network__widget_8h.html#ab6e1ba77e781e8926d64334d87da2014a3a6b9ad5c54a1427455832b2b3097d4f", null ]
    ] ],
    [ "NetworkGameWidgets", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45", [
      [ "WID_NG_MAIN", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45ae339fd8e9f719c6ddf901bb94c4b51de", null ],
      [ "WID_NG_CLIENT_LABEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a889aadba558c30fb4c4a8e7b6c0c8223", null ],
      [ "WID_NG_CLIENT", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a01e09e0e470d066e3d251dd2706e1844", null ],
      [ "WID_NG_FILTER_LABEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a3fc1425dfcc3c7e9485ff0dd4754ccef", null ],
      [ "WID_NG_FILTER", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aebb244c75fe9fdc629db7d10fffdb97f", null ],
      [ "WID_NG_HEADER", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a075c59ddb33422e101305235efdfbf42", null ],
      [ "WID_NG_NAME", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45ac2f3e2da170056945967ed1018181dec", null ],
      [ "WID_NG_CLIENTS", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a0c8b7ae545cc8d28496ecdb0a73c6bb9", null ],
      [ "WID_NG_MAPSIZE", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aa397f817c0c224f0a2ef56226ef81f84", null ],
      [ "WID_NG_DATE", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a778cc29c33284d902b62a17aec6ce631", null ],
      [ "WID_NG_YEARS", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a33996241b9a4c8673b68f363d3f55ddf", null ],
      [ "WID_NG_INFO", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aaebaead8491d0963e77eb03865ae8e8d", null ],
      [ "WID_NG_MATRIX", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a7ae8bb002bbbc1fd44d277fa6a9013c8", null ],
      [ "WID_NG_SCROLLBAR", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a1eef989849fa807d1147ad49fd1cf967", null ],
      [ "WID_NG_LASTJOINED_LABEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45af12260e504eb69235b5ff7073b3dd296", null ],
      [ "WID_NG_LASTJOINED", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a79b38375b7fa9faa22536d799179ff21", null ],
      [ "WID_NG_LASTJOINED_SPACER", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a766140d28c203c81dd00613d0318fc3a", null ],
      [ "WID_NG_DETAILS", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aa5dc5cd8b103625f6c0d686e0cc969b4", null ],
      [ "WID_NG_DETAILS_SPACER", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45adfe15c2e7fcea014b05705eb2abdd8fe", null ],
      [ "WID_NG_JOIN", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a940e7423adc7abc1aae0bd4e21d23879", null ],
      [ "WID_NG_REFRESH", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45ae3561e0bd887108906a495b424250d6c", null ],
      [ "WID_NG_NEWGRF", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45af3554c1b58b78df1c0226a4984539cdc", null ],
      [ "WID_NG_NEWGRF_SEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a8e6e742407c970c624e570ce41164ad7", null ],
      [ "WID_NG_NEWGRF_MISSING", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a73f1afe6899c6f7d2c1fc4cf7ecadce7", null ],
      [ "WID_NG_NEWGRF_MISSING_SEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a49f296666543b39ad4eaa56ac16637eb", null ],
      [ "WID_NG_SEARCH_INTERNET", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a6360191c2445934ed47c1338f77e1f31", null ],
      [ "WID_NG_SEARCH_LAN", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45a9fd10a1b8af7610cd67dc15923be1152", null ],
      [ "WID_NG_ADD", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45acf12ff8dd6f1b4158f22c746a47a91a1", null ],
      [ "WID_NG_START", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45aa522a2402d1ac27481caa2057fd5f746", null ],
      [ "WID_NG_CANCEL", "d8/d61/network__widget_8h.html#a59f7a25d304fea46b1e8a15b8ace4b45ac7762180c1a2540351087e2b57280377", null ]
    ] ],
    [ "NetworkJoinStatusWidgets", "d8/d61/network__widget_8h.html#a763130b21af0ad7e580ddee81a70a6b8", [
      [ "WID_NJS_BACKGROUND", "d8/d61/network__widget_8h.html#a763130b21af0ad7e580ddee81a70a6b8a6de9aafb5a70cea652951f045a57d822", null ],
      [ "WID_NJS_CANCELOK", "d8/d61/network__widget_8h.html#a763130b21af0ad7e580ddee81a70a6b8ab1657760fc411c762cc227baee73e013", null ]
    ] ],
    [ "NetworkLobbyWidgets", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220", [
      [ "WID_NL_BACKGROUND", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a05b7f5c774227b0438cc7b7c6eb721bf", null ],
      [ "WID_NL_TEXT", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a0dd2a8b5ed8db4b188494a9bb630a8fc", null ],
      [ "WID_NL_HEADER", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220aa0480c1dbae3996955d158d683efecca", null ],
      [ "WID_NL_MATRIX", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220ad52da3286b68fab063dfb104a8bfad61", null ],
      [ "WID_NL_SCROLLBAR", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a57c46cfcd5c5f4a24a8f0a18bdd5a3e1", null ],
      [ "WID_NL_DETAILS", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220af79cb692bffc5981486f40759d566980", null ],
      [ "WID_NL_JOIN", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220ae057b7478bfb28c97aa14f5062bf5b10", null ],
      [ "WID_NL_NEW", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a3000949b02779104d482bcbce55e8afe", null ],
      [ "WID_NL_SPECTATE", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220aa690bee3902240b34119b88fb113feba", null ],
      [ "WID_NL_REFRESH", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220aa60c961eb88e777df4a2d517cabd86c3", null ],
      [ "WID_NL_CANCEL", "d8/d61/network__widget_8h.html#ab75a81303f96c085596693b41f891220a8573c5bdac77291a456af1ec56ebe717", null ]
    ] ],
    [ "NetworkStartServerWidgets", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833", [
      [ "WID_NSS_BACKGROUND", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833af52d2afb64869e427d62a35bc17c9974", null ],
      [ "WID_NSS_GAMENAME_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a867bda307263cbf4967419baabed42f5", null ],
      [ "WID_NSS_GAMENAME", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a508cd3b44b352da718f8f83db274cf3c", null ],
      [ "WID_NSS_SETPWD", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ad519409efa1ecf8b9493f068136e198d", null ],
      [ "WID_NSS_CONNTYPE_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ac5324995abb303eeb4480730f93b1f9e", null ],
      [ "WID_NSS_CONNTYPE_BTN", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ac8b47c2be7e1e0ac5c13db3c9b866e29", null ],
      [ "WID_NSS_CLIENTS_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a200a60df467983743c7da56957d4419e", null ],
      [ "WID_NSS_CLIENTS_BTND", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a4fb8af97abbb32965b935dacfc7fb71b", null ],
      [ "WID_NSS_CLIENTS_TXT", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a4dd014db65815066da2ec59568218f32", null ],
      [ "WID_NSS_CLIENTS_BTNU", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833aeafeb1fceaa8af11999def1eb102d8fe", null ],
      [ "WID_NSS_COMPANIES_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a1e368de3d28b73fe0429e2e97f982463", null ],
      [ "WID_NSS_COMPANIES_BTND", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ad3c55eb8d34c14d367d7cf20f04b012c", null ],
      [ "WID_NSS_COMPANIES_TXT", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833aed786417e69a6faa1b3f2efb9313ee91", null ],
      [ "WID_NSS_COMPANIES_BTNU", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a14679fea39052542c828cde07428e5b9", null ],
      [ "WID_NSS_SPECTATORS_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ab21f43474c57c9952f91b1e7d254972b", null ],
      [ "WID_NSS_SPECTATORS_BTND", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a79533e6f35d4e734910873c3bc0efea4", null ],
      [ "WID_NSS_SPECTATORS_TXT", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833accb8eaff704a804b3cdf29dd83505e7d", null ],
      [ "WID_NSS_SPECTATORS_BTNU", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a0c96a06d779fef36fdd0292c09ff74f9", null ],
      [ "WID_NSS_LANGUAGE_LABEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a4d006e0ef2eb28d4b8c89bd8d45d4e79", null ],
      [ "WID_NSS_LANGUAGE_BTN", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a5a31c158e30b06d108b4c4593ca90b09", null ],
      [ "WID_NSS_GENERATE_GAME", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833ac1a6d8a773fe7fc6a808aa02af5a4901", null ],
      [ "WID_NSS_LOAD_GAME", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833aa7a9a1ad4a8a9be1dd96aa067a1479fc", null ],
      [ "WID_NSS_PLAY_SCENARIO", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833af6414f0ac0bc6d27e392143eeb747c73", null ],
      [ "WID_NSS_PLAY_HEIGHTMAP", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a7062ae05eeb8b6ad9be6946d1cab5e79", null ],
      [ "WID_NSS_CANCEL", "d8/d61/network__widget_8h.html#a020ee8048ec437fb45b309d86edec833a6d36e6ba137e2e41abb57509f85e16c6", null ]
    ] ]
];
